@@ -23,5 +23,5 @@ class Configurator(metaclass=Singleton):
             self.config = json.load(f)
 
     def get_message_sender_setting(self):
-        settings = MessageSenderSetting(self.config['wxwork_app'])
+        settings = MessageSenderSetting(self.config['message_sender'])
         return settings
