@@ -5,13 +5,20 @@ HELP_MSG = '''
 surfing <command> [<args>]
 
 The most commonly used commands are:
-    init_raw                 setup raw database
-    init_basic               setup basic database
-    init_derived             setup derived database
-    init_view                setup view database
+    init_raw                setup raw database
+    init_basic              setup basic database
+    init_derived            setup derived database
+    init_view               setup view database
+    download_raw            download raw data
+    update_basic            update basic data base on raw data
+    update_derived          update derived data based on basic and raw data
+    update_view             update view data based on basic and derived data
+    data_update             run download_raw, update_basic, update_derived and update_view in turn
 '''
 
 class SurfingEntrance(object):
+    # TODO: rename to Surfing and move parser out of __init__
+    # Make this class usable in other scripts
 
     def __init__(self):
         parser = argparse.ArgumentParser(description='Fund Command Tool', usage=HELP_MSG)
@@ -72,7 +79,7 @@ class SurfingEntrance(object):
 
         rq_license = SurfingConfigurator().get_license_settings('rq')
         raw_data_downloader = RawDataDownloader(rq_license)
-        raw_data_downloader.download(yesterday, yesterday)
+        return raw_data_downloader.download(yesterday, yesterday)
     
     def update_basic(self, yesterday=None):
         if not yesterday:
@@ -81,44 +88,58 @@ class SurfingEntrance(object):
         from .data.fund.basic.basic_data_processor import BasicDataProcessor
 
         basic_data_processor = BasicDataProcessor()
-        basic_data_processor.process_all(yesterday, yesterday)
+        return basic_data_processor.process_all(yesterday, yesterday)
     
     def update_derived(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
 
-        # from .data.fund.derived.derived_data_processor import DerivedDataProcessor
-        # DerivedDataProcessor().process(yesterday, yesterday)
+        from .data.fund.derived.derived_data_processor import DerivedDataProcessor
+        return DerivedDataProcessor().process_all(yesterday, yesterday)
 
     def update_view(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
 
         from .data.fund.view.view_data_processor import ViewDataProcessor
-        ViewDataProcessor().process(yesterday, yesterday)
+        return ViewDataProcessor().process_all(yesterday, yesterday)
 
     def data_update(self):
         print('Start data update')
 
         yesterday = self._get_yesterday()
 
-        print('Step 0. Start data download')
-        self.download_raw(yesterday)
-        print('Step 0. Done data download')
+        failed_tasks = {}
 
-        print('Step 1. Start update basic')
-        self.update_basic(yesterday)
-        print('Step 1. Done update basic')
+        print('Step 1. Start raw data download')
+        raw_failed_tasks = self.download_raw(yesterday)
+        if len(raw_failed_tasks) > 0:
+            failed_tasks['raw'] = raw_failed_tasks
+        print('Step 1. Done raw data download')
 
-        print('Step 2. Start update derived')
-        self.update_derived(yesterday)
-        print('Step 2. Done update derived')
+        print('Step 2. Start update basic')
+        basic_failed_tasks = self.update_basic(yesterday)
+        if len(basic_failed_tasks) > 0:
+            failed_tasks['basic'] = basic_failed_tasks
+        print('Step 2. Done update basic')
+
+        print('Step 3. Start update derived')
+        derived_failed_tasks = self.update_derived(yesterday)
+        if len(derived_failed_tasks) > 0:
+            failed_tasks['derived'] = derived_failed_tasks
+        print('Step 3. Done update derived')
         
-        print('Step 3. Start update view')
-        self.update_view(yesterday)
-        print('Step 3. Done update view')
+        print('Step 4. Start update view')
+        view_failed_tasks = self.update_view(yesterday)
+        if len(view_failed_tasks) > 0:
+            failed_tasks['view'] = view_failed_tasks
+        print('Step 4. Done update view')
 
         print('Done data update')
+
+        from .util.wechat_bot import WechatBot
+        wechat_bot = WechatBot()
+        wechat_bot.send_data_update_status(yesterday, failed_tasks)
     
 
 if __name__ == "__main__":
