@@ -51,4 +51,17 @@ class DerivedDataApi(object):
                 print(e)
                 return pd.DataFrame([])
 
-
+    def get_index_valuation_develop(self, index_id, start_date):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    IndexValuationDevelop
+                ).filter(
+                    IndexValuationDevelop.index_id == index_id,
+                    IndexValuationDevelop.datetime >= start_date,
+                ).order_by(IndexValuationDevelop.datetime.asc())
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print(e)
+                return pd.DataFrame([])
