@@ -9,6 +9,10 @@ class RawDataDownloader(object):
         self.em_downloader = EmRawDataDownloader()
 
     def download(self, start_date, end_date):
-        self.rq_downloader.download_all(start_date, end_date)
-        self.web_downloader.download_all(start_date, end_date)
-        self.em_downloader.download_all(start_date, end_date)
+        failed_tasks = []
+
+        failed_tasks.extend(self.rq_downloader.download_all(start_date, end_date))
+        failed_tasks.extend(self.web_downloader.download_all(start_date, end_date))
+        failed_tasks.extend(self.em_downloader.download_all(start_date, end_date))
+        
+        return failed_tasks
