@@ -1,4 +1,5 @@
 import pandas as pd
+import traceback
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
@@ -206,81 +207,93 @@ class FundDailyCollectionProcessor(object):
             return x
 
     def compute_daily_collection(self):
-        funds = self.get_fund_df()
-        funds = funds.reset_index()
-        funds = funds.drop_duplicates(subset=['fund_id'], keep='last')
-        funds = funds.set_index('fund_id')
-        print('info', funds)
-        print('-' * 100)
+        try:
+            funds = self.get_fund_df()
+            funds = funds.reset_index()
+            funds = funds.drop_duplicates(subset=['fund_id'], keep='last')
+            funds = funds.set_index('fund_id')
+            print('info', funds)
+            print('-' * 100)
 
-        nav, latest_time = self.get_nav_df()
-        print(latest_time)
-        nav = nav.reset_index()
-        nav = nav.drop_duplicates(subset=['fund_id'], keep='last')
-        nav = nav.set_index('fund_id')
-        print('nav', nav)
-        print('-' * 100)
+            nav, latest_time = self.get_nav_df()
+            print(latest_time)
+            nav = nav.reset_index()
+            nav = nav.drop_duplicates(subset=['fund_id'], keep='last')
+            nav = nav.set_index('fund_id')
+            print('nav', nav)
+            print('-' * 100)
 
-        alpha = self.get_alpha_df()
-        alpha = alpha.set_index('fund_id')
-        print(alpha)
-        print('-' * 100)
-        size = self.get_size_df()
-        print(size)
-        print('-' * 100)
-        score = self.get_score_df().set_index('fund_id')
-        print(score)
-        print('-' * 100)
-        tag_indicator = self.get_tag_fund_indicator_df().set_index('fund_id')
-        print(tag_indicator)
-        print('-' * 100)
+            alpha = self.get_alpha_df()
+            alpha = alpha.set_index('fund_id')
+            print(alpha)
+            print('-' * 100)
+            size = self.get_size_df()
+            print(size)
+            print('-' * 100)
+            score = self.get_score_df().set_index('fund_id')
+            print(score)
+            print('-' * 100)
+            tag_indicator = self.get_tag_fund_indicator_df().set_index('fund_id')
+            print(tag_indicator)
+            print('-' * 100)
 
-        print('处理机构评级')
-        rating = self.get_institution_rating_df()
-        rating = rating.drop_duplicates(subset=['fund_id'], keep='last')
-        rating = rating.set_index('fund_id')
-        print(rating)
-        print('-' * 100)
+            print('处理机构评级')
+            rating = self.get_institution_rating_df()
+            rating = rating.drop_duplicates(subset=['fund_id'], keep='last')
+            rating = rating.set_index('fund_id')
+            print(rating)
+            print('-' * 100)
 
-        print('处理净值')
-        df = pd.concat([funds, nav, alpha, size, rating, score, tag_indicator], axis=1, sort=False)
-        df.index.name = 'fund_id'
-        print('_'*100)
-        print(df)
+            print('处理净值')
+            df = pd.concat([funds, nav, alpha, size, rating, score, tag_indicator], axis=1, sort=False)
+            df.index.name = 'fund_id'
+            print('_'*100)
+            print(df)
 
-        print('处理行情')
-        indicator = self.get_indicator_df()
-        indicator = indicator.dropna(subset=['order_book_id'])
-        indicator['fund_id'] = indicator['order_book_id'] + '!0'
-        indicator = indicator.drop_duplicates(subset=['order_book_id'], keep='last')
-        indicator = indicator.drop(['order_book_id'], axis=1)
-        indicator = indicator.set_index('fund_id')
-        print(indicator)
-        print('-' * 100)
+            print('处理行情')
+            indicator = self.get_indicator_df()
+            indicator = indicator.dropna(subset=['order_book_id'])
+            indicator['fund_id'] = indicator['order_book_id'] + '!0'
+            indicator = indicator.drop_duplicates(subset=['order_book_id'], keep='last')
+            indicator = indicator.drop(['order_book_id'], axis=1)
+            indicator = indicator.set_index('fund_id')
+            print(indicator)
+            print('-' * 100)
 
-        df = pd.concat([df, indicator.reindex(index=df.index)], axis=1, sort=False)
-        df.index.name = 'fund_id'
-        df = df.reset_index()
-        df = df.dropna(subset=['fund_id'])
-        df['exchange_status'] = df.apply(self.get_exchange_status, axis=1)
-        df['found_to_now'] = df['start_date'].apply(self.get_found_to_now)
-        df['manager_id'] = df['manager_id'].apply(self.modify_fund_manager)
-        df = df.rename(columns={
-            'wind_class_1': 'wind_class_I',
-            'start_date': 'found_date',
-            'manager_id': 'fund_manager',
-            'company_id': 'company_name',
-            'desc_name': 'symbol',
-        })
-        df = df.drop(['redeem_status', 'subscribe_status'], axis=1)
-        df = df.sort_values(['fund_id'])
-        df = df.drop_duplicates(subset=['order_book_id'], keep='first')
-        df = df.dropna(subset=['order_book_id'])
+            df = pd.concat([df, indicator.reindex(index=df.index)], axis=1, sort=False)
+            df.index.name = 'fund_id'
+            df = df.reset_index()
+            df = df.dropna(subset=['fund_id'])
+            df['exchange_status'] = df.apply(self.get_exchange_status, axis=1)
+            df['found_to_now'] = df['start_date'].apply(self.get_found_to_now)
+            df['manager_id'] = df['manager_id'].apply(self.modify_fund_manager)
+            df = df.rename(columns={
+                'wind_class_1': 'wind_class_I',
+                'start_date': 'found_date',
+                'manager_id': 'fund_manager',
+                'company_id': 'company_name',
+                'desc_name': 'symbol',
+            })
+            df = df.drop(['redeem_status', 'subscribe_status'], axis=1)
+            df = df.sort_values(['fund_id'])
+            df = df.drop_duplicates(subset=['order_book_id'], keep='first')
+            df = df.dropna(subset=['order_book_id'])
 
-        # df.to_csv('./hhh.csv')
-        self.append_data(FundDailyCollection.__tablename__, df)
+            # df.to_csv('./hhh.csv')
+            self.append_data(FundDailyCollection.__tablename__, df)
 
-        print(df)
+            print(df)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_stack()
+            return False
+
+    def process(self):
+        failed_tasks = []
+        if not self.compute_daily_collection():
+            failed_tasks.append('compute_daily_collection')
+        return failed_tasks
 
 
 if __name__ == '__main__':
