@@ -1,4 +1,5 @@
 import pandas as pd
+import traceback
 from ...wrapper.mysql import DerivedDatabaseConnector, BasicDatabaseConnector, ViewDatabaseConnector
 from ...view.view_models import IndexDailyCollection
 from ...view.basic_models import IndexInfo, IndexPrice
@@ -135,27 +136,38 @@ class IndexDailyCollectionProcessor(object):
             print('没有需要插入的新数据')
 
     def collection_daily_index(self):
+        try:
+            print('1、 load data...')
+            info = self.get_index_info()
+            vol = self.get_index_volatility()
+            ret = self.get_index_return()
+            val = self.get_index_valuation()
+            price = self.get_index_price()
 
-        print('1、 load data...')
-        info = self.get_index_info()
-        vol = self.get_index_volatility()
-        ret = self.get_index_return()
-        val = self.get_index_valuation()
-        price = self.get_index_price()
+            print('2、 concat data...')
+            df = pd.concat([info, vol, ret, val, price], axis=1, sort=False)
+            df.index.name = 'index_id'
+            df = df.reset_index()
 
-        print('2、 concat data...')
-        df = pd.concat([info, vol, ret, val, price], axis=1, sort=False)
-        df.index.name = 'index_id'
-        df = df.reset_index()
+            print('3、 special option...')
 
-        print('3、 special option...')
+            df['order_book_id'] = df['order_book_id'].apply(lambda x: x.split('.')[0] if (x and x != 'not_available') else None)
+            df['industry_tag'] = df['industry_tag'].apply(lambda x: x if x != 'not_available' else None)
 
-        df['order_book_id'] = df['order_book_id'].apply(lambda x: x.split('.')[0] if x != 'not_available' else None)
-        df['industry_tag'] = df['industry_tag'].apply(lambda x: x if x != 'not_available' else None)
+            self.append_data(IndexDailyCollection.__tablename__, df)
 
-        self.append_data(IndexDailyCollection.__tablename__, df)
+            print(df)
+            return True
+        except Exception as e:
+            print(e)
+            traceback.print_stack()
+            return False
 
-        print(df)
+    def process(self):
+        failed_tasks = []
+        if not self.collection_daily_index():
+            failed_tasks.append('collection_daily_index')
+        return failed_tasks
 
 
 if __name__ == '__main__':
