@@ -14,10 +14,13 @@ class FundDataTables:
     fund_score: pd.DataFrame = None
     fund_nav: pd.DataFrame = None
     fund_indicator: pd.DataFrame = None
+    fund_unit_nav: pd.DataFrame = None
     # fund helps
     fund_list: set = None
-    index_fund_indicator_pack: pd.DataFrame = None # pivot_table
+    index_list: set = None
     fund_index_map: dict = None # fund_id -> index_id
+    # score helps
+    index_fund_indicator_pack: pd.DataFrame = None # pivot_table
 
     def __post_init__(self):
         self.fund_list = self.fund_list or set([])
@@ -31,8 +34,10 @@ class FundDataTables:
         return s
 
     def _agg_indicator(self):
-        self.index_fund_indicator_pack = self.fund_indicator.pivot_table(index=['datetime', 'index_id', 'fund_id'])
-
+        self.index_fund_indicator_pack = self.fund_indicator.pivot_table(index=['index_id', 'datetime', 'fund_id'])
+        self.index_fund_indicator_pack['ir'] = self.index_fund_indicator_pack['alpha'] / self.index_fund_indicator_pack['track_err']
+        self.index_list = set(self.index_fund_indicator_pack.index.levels[0])
+        
     def fix_data(self):
         # 将 fix_data_v1 去掉的原因是目前 basic 改用choice数据源，nav数据没有这个问题了。
         # self.fix_data_v1()
