@@ -244,6 +244,19 @@ class FundPosition:
         w_dic = { f: w / mv for f, w in w_dic.items() }
         return mv, w_dic
 
+    def calc_asset_position(self,
+            fund_navs: dict,  # fund_id -> nav(adjusted net value)
+            current_index_prices: AssetPrice,  # index_id -> nav(adjusted net value)
+        ):
+        mv_dic = {}
+        for pos_item in self.funds.values():
+            nav = fund_navs.get(pos_item.fund_id, np.nan)
+            assert not np.isnan(nav), f'fund nav vol {pos_item.fund_id} has negative nav!'
+            mv_dic[pos_item.index_id] = nav * pos_item.volume + mv_dic.get(pos_item.index_id, 0)
+        vol_dic = {f: m / current_index_prices.__dict__.get(f) for f, m in mv_dic.items()}
+        vol_dic['cash'] = self.cash
+        return AssetPosition(**vol_dic)
+
     def get_volume(self, fund_id):
         item = self.funds.get(fund_id)
         if not item:
