@@ -36,6 +36,8 @@ class TAAHelper(Helper):
         taa_effected = False
         mode_changed = False
         for index_id, target_w in taa.__dict__.items():
+            if target_w == 0:
+                continue
 
             if index_id in asset_pct:
                 val_pct = asset_pct[index_id]
@@ -75,7 +77,8 @@ class TAAHelper(Helper):
                 taa_effected = taa_effected or new_mode != TAAStatusMode.NORMAL
         taa.rebalance()
         if taa_effected:
-            print(f'taa: {dt} (mode){mode_changed} (taa){taa_effected} (saa){cur_saa} (taa){taa}')
+            #print(f'taa: {dt} (mode){mode_changed} (taa){taa_effected} (saa){cur_saa} (taa){taa}')
+            pass
         return taa
 
     
\ No newline at end of file
